@@ -970,7 +970,7 @@ class EncodeParams(AbstractModel):
 
     def __init__(self):
         """
-        :param AudioSampleRate: 混流-输出流音频采样率。取值为[48000, 44100, 32000,24000,, 16000, 12000, 8000]，单位是Hz。
+        :param AudioSampleRate: 混流-输出流音频采样率。取值为[48000, 44100, 32000, 24000, 16000, 8000]，单位是Hz。
         :type AudioSampleRate: int
         :param AudioBitrate: 混流-输出流音频码率。取值范围[8,500]，单位为Kbps。
         :type AudioBitrate: int
@@ -1102,6 +1102,8 @@ class LayoutParams(AbstractModel):
         :type PresetLayoutConfig: list of PresetLayoutConfig
         :param PlaceHolderMode: 自定义模板中有效，设置为1时代表启用占位图功能，0时代表不启用占位图功能，默认为0。启用占位图功能时，在预设位置的用户没有上行视频时可显示对应的占位图。
         :type PlaceHolderMode: int
+        :param PureAudioHoldPlaceMode: 悬浮模板、九宫格、屏幕分享模板生效，用于控制纯音频上行是否占用画面布局位置。设置为0是代表后台默认处理方式，悬浮小画面占布局位置，九宫格画面占布局位置、屏幕分享小画面不占布局位置；设置为1时代表纯音频上行占布局位置；设置为2时代表纯音频上行不占布局位置。默认为0。
+        :type PureAudioHoldPlaceMode: int
         """
         self.Template = None
         self.MainVideoUserId = None
@@ -1111,6 +1113,7 @@ class LayoutParams(AbstractModel):
         self.MixVideoUids = None
         self.PresetLayoutConfig = None
         self.PlaceHolderMode = None
+        self.PureAudioHoldPlaceMode = None
 
 
     def _deserialize(self, params):
@@ -1129,6 +1132,7 @@ class LayoutParams(AbstractModel):
                 obj._deserialize(item)
                 self.PresetLayoutConfig.append(obj)
         self.PlaceHolderMode = params.get("PlaceHolderMode")
+        self.PureAudioHoldPlaceMode = params.get("PureAudioHoldPlaceMode")
 
 
 class OneSdkAppIdTranscodeTimeUsagesInfo(AbstractModel):
@@ -1202,7 +1206,7 @@ class OutputParams(AbstractModel):
         :type StreamId: str
         :param PureAudioStream: 取值范围[0,1]， 填0：直播流为音视频(默认); 填1：直播流为纯音频
         :type PureAudioStream: int
-        :param RecordId: 自定义录制文件名
+        :param RecordId: 自定义录制文件名。请先在实时音视频控制台开通录制功能，https://cloud.tencent.com/document/product/647/50768
         :type RecordId: str
         :param RecordAudioOnly: 取值范围[0,1]，填0无实际含义; 填1：指定录制文件格式为mp3
         :type RecordAudioOnly: int
@@ -1245,7 +1249,7 @@ class PresetLayoutConfig(AbstractModel):
         :type RenderMode: int
         :param MixInputType: 该当前位置用户混入的流类型：0为混入音视频，1为只混入视频，2为只混入音频。默认为0，建议配合指定用户ID使用。
         :type MixInputType: int
-        :param PlaceImageId: 占位图ID。实时音视频控制台上传并生成，https://cloud.tencent.com/document/product/647/50769
+        :param PlaceImageId: 占位图ID。启用占位图功能时，在当前位置的用户没有上行视频时显示占位图。占位图在实时音视频控制台上传并生成，https://cloud.tencent.com/document/product/647/50769
         :type PlaceImageId: int
         """
         self.UserId = None
@@ -1273,6 +1277,27 @@ class PresetLayoutConfig(AbstractModel):
         self.PlaceImageId = params.get("PlaceImageId")
 
 
+class PublishCdnParams(AbstractModel):
+    """第三方CDN转推参数
+
+    """
+
+    def __init__(self):
+        """
+        :param BizId: 腾讯云直播BizId。
+        :type BizId: int
+        :param PublishCdnUrls: 第三方CDN转推的目的地址，同时只支持转推一个第三方CDN地址。
+        :type PublishCdnUrls: list of str
+        """
+        self.BizId = None
+        self.PublishCdnUrls = None
+
+
+    def _deserialize(self, params):
+        self.BizId = params.get("BizId")
+        self.PublishCdnUrls = params.get("PublishCdnUrls")
+
+
 class QualityData(AbstractModel):
     """Es返回的质量数据
 
@@ -1674,12 +1699,15 @@ class StartMCUMixTranscodeByStrRoomIdRequest(AbstractModel):
         :type EncodeParams: :class:`tencentcloud.trtc.v20190722.models.EncodeParams`
         :param LayoutParams: 混流输出布局参数。
         :type LayoutParams: :class:`tencentcloud.trtc.v20190722.models.LayoutParams`
+        :param PublishCdnParams: 第三方CDN转推参数。
+        :type PublishCdnParams: :class:`tencentcloud.trtc.v20190722.models.PublishCdnParams`
         """
         self.SdkAppId = None
         self.StrRoomId = None
         self.OutputParams = None
         self.EncodeParams = None
         self.LayoutParams = None
+        self.PublishCdnParams = None
 
 
     def _deserialize(self, params):
@@ -1694,6 +1722,9 @@ class StartMCUMixTranscodeByStrRoomIdRequest(AbstractModel):
         if params.get("LayoutParams") is not None:
             self.LayoutParams = LayoutParams()
             self.LayoutParams._deserialize(params.get("LayoutParams"))
+        if params.get("PublishCdnParams") is not None:
+            self.PublishCdnParams = PublishCdnParams()
+            self.PublishCdnParams._deserialize(params.get("PublishCdnParams"))
 
 
 class StartMCUMixTranscodeByStrRoomIdResponse(AbstractModel):
@@ -1730,12 +1761,15 @@ class StartMCUMixTranscodeRequest(AbstractModel):
         :type EncodeParams: :class:`tencentcloud.trtc.v20190722.models.EncodeParams`
         :param LayoutParams: 混流输出布局参数。
         :type LayoutParams: :class:`tencentcloud.trtc.v20190722.models.LayoutParams`
+        :param PublishCdnParams: 第三方CDN转推参数。
+        :type PublishCdnParams: :class:`tencentcloud.trtc.v20190722.models.PublishCdnParams`
         """
         self.SdkAppId = None
         self.RoomId = None
         self.OutputParams = None
         self.EncodeParams = None
         self.LayoutParams = None
+        self.PublishCdnParams = None
 
 
     def _deserialize(self, params):
@@ -1750,6 +1784,9 @@ class StartMCUMixTranscodeRequest(AbstractModel):
         if params.get("LayoutParams") is not None:
             self.LayoutParams = LayoutParams()
             self.LayoutParams._deserialize(params.get("LayoutParams"))
+        if params.get("PublishCdnParams") is not None:
+            self.PublishCdnParams = PublishCdnParams()
+            self.PublishCdnParams._deserialize(params.get("PublishCdnParams"))
 
 
 class StartMCUMixTranscodeResponse(AbstractModel):
